import{l as e,o as r}from"./entry_page.js";import{d as o,E as i,a}from"./Dashboard.EnterpriseViewOnlyPreset.DHDF7xhT.js";import{w as s,g as n}from"./Dashboard.utils.DCnVQca0.js";import{F as p}from"./Dashboard.consts.BpCQqH5Z.js";import"./toUpper.BNt1QE2_.js";import"./ErrorBoundary.BjiCoH_C.js";import"./ChevronLeft.DxnwXrVH.js";import"./ArrowBroadUnderbarDown.Dr75X1l6.js";const h=({dashboardDefinition:t})=>(e.useEffect(()=>(s('[data-input-id="overview_input"]',"#overview_main_label_viz"),()=>{}),[]),t?r.jsx(o.DashboardContextProvider,{preset:i,initialDefinition:t,featureFlags:p,children:r.jsx(a.DashboardCore,{width:"99%",height:"auto",actionMenus:n("overview")})}):null);export{h as OverviewDashboard,h as default};
