import{o as t}from"./entry_page.js";import{d as o,E as s,a as e}from"./Dashboard.EnterpriseViewOnlyPreset.DHDF7xhT.js";import"./toUpper.BNt1QE2_.js";import"./ErrorBoundary.BjiCoH_C.js";import"./ChevronLeft.DxnwXrVH.js";const n=({dashboardDefinition:r})=>r?t.jsx(o.DashboardContextProvider,{preset:s,initialDefinition:r,children:t.jsx(e.DashboardCore,{width:"100%",height:"auto"})}):null;export{n as CustomDashboard,n as default};
